aboutsummaryrefslogtreecommitdiffstats
path: root/build/src
diff options
context:
space:
mode:
authorwisberg <wisberg>2004-04-05 05:17:58 +0000
committerwisberg <wisberg>2004-04-05 05:17:58 +0000
commitd47986d2939eb961e756c6136663c5e0dddc136a (patch)
treec273bc8ff5c71b415b52ba757c152be99fb94024 /build/src
parentb66f05a7abef6e187fb7e8bbe34a3c3e509e2321 (diff)
downloadaspectj-d47986d2939eb961e756c6136663c5e0dddc136a.tar.gz
aspectj-d47986d2939eb961e756c6136663c5e0dddc136a.zip
untested code to skip any /tools.jar library antecedant when building other that testing jars
Diffstat (limited to 'build/src')
-rw-r--r--build/src/org/aspectj/internal/tools/build/Module.java8
1 files changed, 6 insertions, 2 deletions
diff --git a/build/src/org/aspectj/internal/tools/build/Module.java b/build/src/org/aspectj/internal/tools/build/Module.java
index b2ba39b4b..5cc292246 100644
--- a/build/src/org/aspectj/internal/tools/build/Module.java
+++ b/build/src/org/aspectj/internal/tools/build/Module.java
@@ -112,7 +112,7 @@ public class Module {
}
}
/** XXX gack explicitly skip Ant except for testing... modules */
private static boolean skipLibraryJarAntecedant(Module module, File libJar) {
if (null == libJar) {
return true;
@@ -120,7 +120,11 @@ public class Module {
if (!module.name.startsWith("testing")) {
String path = libJar.getPath().replace('\\', '/');
path = path.replace(File.separatorChar, '/');
- return (-1 != path.indexOf("/lib/ant/lib/"));
+ if (-1 != path.indexOf("/lib/ant/lib/")) {
+ return true;
+ } else if (-1 != path.indexOf("/tools.jar")) {
+ return true;
+ }
}
return false;
}
@@ -112,7 +112,7 @@ public class Module {
}
}
- /** XXX gack explicitly skip Ant except for testing... modules */
+ /** XXX gack explicitly skip Ant, sun tools.jar except for testing... modules */
private static boolean skipLibraryJarAntecedant(Module module, File libJar) {
if (null == libJar) {